.. highlight:: shell

=============
Contributors
=============

* John Preston
    * `Keybase <https://keybase.io/johnpreston78>`_ |JohnPreston78PGP|
    * `Github <https://github.com/johnpreston>`_

* Harold Spencer Jr.
    * `Keybase <https://keybase.io/hspencer77>`_ |HSpencer77PGP|
    * `Github <https://github.com/hspencer77>`_


.. |JohnPreston78PGP| image:: https://img.shields.io/keybase/pgp/johnpreston78
.. |HSpencer77PGP| image:: https://img.shields.io/keybase/pgp/hspencer77

